# SpeechAi

[![Release](https://img.shields.io/pypi/v/speechai?label=release)](https://pypi.org/project/speechai/)
[![Downloads](https://static.pepy.tech/badge/speechai/month)](https://pepy.tech/project/speechai)
[![lint](https://github.com/nicolasebastianelli/speech-ai/actions/workflows/ci.yaml/badge.svg)](https://github.com/nicolasebastianelli/speech-ai/actions/workflows/ci.yaml)
[![lint](https://github.com/nicolasebastianelli/speech-ai/actions/workflows/cd.yaml/badge.svg)](https://github.com/nicolasebastianelli/speech-ai/workflows/cd.yaml)
[![License](https://img.shields.io/pypi/l/speechai.svg)](https://github.com/nicolasebastianelli/speech-ai/blob/main/LICENSE)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/imports-isort-edfaca.svg)](https://pycqa.github.io/isort/)
[![Imports: isort](https://img.shields.io/badge/linter-flake8-a63d42.svg)](https://github.com/PyCQA/flake8)
[![Imports: isort](https://img.shields.io/badge/linter-pylint-5e8db2.svg)](https://github.com/pylint-dev/pylint)
[![Imports: isort](https://img.shields.io/badge/test-pytest-f2c3c9.svg)](https://docs.pytest.org/en/7.3.x/)
